@@ -4,7 +4,7 @@ pub mod field;
 
 pub use self::field::Field;
 
-use std::{convert::TryFrom, error, fmt, ops::Deref};
+use std::{error, fmt, ops::Deref};
 
 use indexmap::IndexMap;
 
@@ -67,7 +67,6 @@ impl Genotype {
     /// # Examples
     ///
     /// ```
-    /// # use std::convert::TryFrom;
     /// use noodles_vcf::record::genotypes::{genotype::{field::{Key, Value}, Field}, Genotype};
     ///
     /// let format = "GT:GQ".parse()?;
@@ -106,7 +105,6 @@ impl Genotype {
     /// # Examples
     ///
     /// ```
-    /// # use std::convert::TryFrom;
     /// use noodles_vcf::record::{genotypes::{genotype::{field::{Key, Value}, Field}, Genotype}};
     /// let genotype = Genotype::from_str_format("0|0:13", &"GT:GQ".parse()?)?;
     /// assert_eq!(genotype.genotype(), Some(Ok("0|0".parse()?)));
